@@ -3,6 +3,7 @@ from __future__ import annotations
 import sys
 
 import pytest
+from custom_exceptions import PythonMyException7
 
 import env
 import pybind11_cross_module_tests as cm
@@ -75,9 +76,10 @@ def test_cross_module_exceptions(msg):
 
 # TODO: FIXME
 @pytest.mark.xfail(
-    "env.MACOS and (env.PYPY or pybind11_tests.compiler_info.startswith('Homebrew Clang')) or sys.platform.startswith('emscripten')",
+    "env.MACOS and env.PYPY",
     raises=RuntimeError,
     reason="See Issue #2847, PR #2999, PR #4324",
+    strict=not env.PYPY,  # PR 5569
 )
 def test_cross_module_exception_translator():
     with pytest.raises(KeyError):
@@ -103,28 +105,24 @@ def ignore_pytest_unraisable_warning(f):
 @pytest.mark.xfail(env.PYPY, reason="Failure on PyPy 3.8 (7.3.7)", strict=False)
 @ignore_pytest_unraisable_warning
 def test_python_alreadyset_in_destructor(monkeypatch, capsys):
-    hooked = False
     triggered = False
 
-    if hasattr(sys, "unraisablehook"):  # Python 3.8+
-        hooked = True
-        # Don't take `sys.unraisablehook`, as that's overwritten by pytest
-        default_hook = sys.__unraisablehook__
+    # Don't take `sys.unraisablehook`, as that's overwritten by pytest
+    default_hook = sys.__unraisablehook__
 
-        def hook(unraisable_hook_args):
-            exc_type, exc_value, exc_tb, err_msg, obj = unraisable_hook_args
-            if obj == "already_set demo":
-                nonlocal triggered
-                triggered = True
-            default_hook(unraisable_hook_args)
-            return
+    def hook(unraisable_hook_args):
+        exc_type, exc_value, exc_tb, err_msg, obj = unraisable_hook_args
+        if obj == "already_set demo":
+            nonlocal triggered
+            triggered = True
+        default_hook(unraisable_hook_args)
+        return
 
-        # Use monkeypatch so pytest can apply and remove the patch as appropriate
-        monkeypatch.setattr(sys, "unraisablehook", hook)
+    # Use monkeypatch so pytest can apply and remove the patch as appropriate
+    monkeypatch.setattr(sys, "unraisablehook", hook)
 
     assert m.python_alreadyset_in_destructor("already_set demo") is True
-    if hooked:
-        assert triggered is True
+    assert triggered is True
 
     _, captured_stderr = capsys.readouterr()
     assert captured_stderr.startswith("Exception ignored in: 'already_set demo'")
@@ -199,7 +197,12 @@ def test_custom(msg):
             raise RuntimeError("Exception error: caught child from parent") from err
     assert msg(excinfo.value) == "this is a helper-defined translated exception"
 
+    with pytest.raises(PythonMyException7) as excinfo:
+        m.throws7()
+    assert msg(excinfo.value) == "[PythonMyException7]: abc"
 
+
+@pytest.mark.xfail("env.GRAALPY", reason="TODO should get fixed on GraalPy side")
 def test_nested_throws(capture):
     """Tests nested (e.g. C++ -> Python -> C++) exception handling"""
 
@@ -368,6 +371,7 @@ def _test_flaky_exception_failure_point_init_py_3_12():
     "env.PYPY and sys.version_info[:2] < (3, 12)",
     reason="PyErr_NormalizeException Segmentation fault",
 )
+@pytest.mark.xfail("env.GRAALPY", reason="TODO should be fixed on GraalPy side")
 def test_flaky_exception_failure_point_init():
     if sys.version_info[:2] < (3, 12):
         _test_flaky_exception_failure_point_init_before_py_3_12()
@@ -375,6 +379,7 @@ def test_flaky_exception_failure_point_init():
         _test_flaky_exception_failure_point_init_py_3_12()
 
 
+@pytest.mark.xfail("env.GRAALPY", reason="TODO should be fixed on GraalPy side")
 def test_flaky_exception_failure_point_str():
     what, py_err_set_after_what = m.error_already_set_what(
         FlakyException, ("failure_point_str",)
