@@ -21,6 +21,7 @@ def test_nested_modules():
     )
     assert m.__name__ == "pybind11_tests.modules"
     assert ms.__name__ == "pybind11_tests.modules.subsubmodule"
+    assert m.__file__ == ms.__file__
 
     assert ms.submodule_func() == "submodule_func()"
 
@@ -39,6 +40,9 @@ def test_reference_internal():
     assert str(b.get_a2()) == "A[43]"
     assert str(b.a2) == "A[43]"
 
+    if env.GRAALPY:
+        pytest.skip("ConstructorStats is incompatible with GraalPy.")
+
     astats, bstats = ConstructorStats.get(ms.A), ConstructorStats.get(ms.B)
     assert astats.alive() == 2
     assert bstats.alive() == 1
@@ -78,6 +82,13 @@ def test_pydoc():
     assert pydoc.text.docmodule(pybind11_tests)
 
 
+def test_module_handle_type_name():
+    assert (
+        m.def_submodule.__doc__
+        == "def_submodule(arg0: types.ModuleType, arg1: str) -> types.ModuleType\n"
+    )
+
+
 def test_duplicate_registration():
     """Registering two things with the same name"""
 
@@ -97,9 +108,9 @@ def test_def_submodule_failures():
     sm = m.def_submodule(m, b"ScratchSubModuleName")  # Using bytes to show it works.
     assert sm.__name__ == m.__name__ + "." + "ScratchSubModuleName"
     malformed_utf8 = b"\x80"
-    if env.PYPY:
+    if env.PYPY or env.GRAALPY:
         # It is not worth the effort finding a trigger for a failure when running with PyPy.
-        pytest.skip("Sufficiently exercised on platforms other than PyPy.")
+        pytest.skip("Sufficiently exercised on platforms other than PyPy/GraalPy.")
     else:
         # Meant to trigger PyModule_GetName() failure:
         sm_name_orig = sm.__name__
